# -*- coding: iso-8859-1 -*-
# Copyright (C) 2013 Bastian Kleineidam
"""
Comicfury comic strips
"""
from re import compile
from ..scraper import make_scraper
from ..util import tagre
from ..helpers import bounceStarter


_imageSearch = compile(tagre("img", "src", r'([^"]+)', after='comicimage'))
_prevSearch = compile(tagre("a", "href", r'(/comics/\d+)', after='prev'))
_nextSearch = compile(tagre("a", "href", r'(/comics/\d+)', after='next'))

def add(name, url, description):
    classname = 'ComicFury_%s' % name

    @classmethod
    def namer(cls, imageUrl, pageUrl):
        parts = pageUrl.split('/')
        num = parts[-1]
        return "%s_%s" % (name, num)

    globals()[classname] = make_scraper(classname,
        name='ComicFury/' + name,
        description = description,
        url = url,
        stripUrl = url + '%s',
        starter = bounceStarter(url, _nextSearch),
        imageSearch = _imageSearch,
        prevSearch = _prevSearch,
        help = 'Index format: none',
        namer = namer,
    )

# do not edit anything below since these entries are generated from scripts/update.sh
# DO NOT REMOVE
#add('1000', 'http://1000.thecomicseries.com/', u'A nonfiction comedy. GO TO www.l80comics.com TO CONTINUE READING, AS I AM NO LONGER HOSTING ON COMICFURY. Sorry! :O') # 259
add('1234567902791', 'http://1234567902791.thecomicseries.com/', u"The comic in when a happily, retarded knight, a hateful wizard, a demon thief, and a darkened thing go on random quests facing dangerous monsters, characters, and the most challenging, themselves. You've never seen a game like this. Super RPG.") # 273
add('12yearslater', 'http://12yearslater.thecomicseries.com/', u'This is a strip comic about two different moments. One of them happens a certain number of years after the other- I bet you can guess how many.') # 210
add('6colorstories', 'http://6colorstories.thecomicseries.com/', u'') # 111
add('AAB', 'http://AAB.thecomicseries.com/', u"This is where I plan on sticking all my non-cannon Frostbound, and miscellaneous art for your enjoyment. Any fan art that get's draw for Frostbound will also end up here.") # 100
add('AccidentallyonPurpose', 'http://Accidentally-on-Purpose.thecomicseries.com/', u'A Warlock, a Guitarist, and a Host for a demon live under the same roof and are in a three way relationship. As things go upside down and right side up again, there seems to be quite a few issues in their lives, even though the three of them seem to still make it through okay, minus the huge bills they have to pay to their landlord...') # 100
add('Acryden', 'http://acryden.thecomicseries.com/', u"We've just launched The Acryden printing drive at Indiegogo! With everyone's help we can print our comic, we've also whipped up some pretty cool rewards for lending a hand! http://www.indiegogo.com/theacryden?a=1639090 In order to stop an intergalactic catastrophe, a team of unlikely heroes must travel across the universe and track down a dangerous magical item that has once again come into existence. Visit the main site at www.acryden.com") # 156
add('Actingout', 'http://actingout.thecomicseries.com/', u"When a bunch of kids with very different personalities come together in their school's drama club, a lot more goes on in the auditorium than you may think! Follow the dramatic lives of Clinton, Ollie, Tasha, and the rest of the gang as they set the scene and put on a heck of a performance, both on and off the stage! Updates are on Sundays and Thursdays!") # 184
add('Adventuresofjonas', 'http://adventuresofjonas.thecomicseries.com/', u"These short, scribbely orange comics are excerpts from my life through my own slanted viewpoint .. they are totally out of context. Its mostly disjointed vignettes, relationships, inside jokes, a couple nifty thoughts and dumb adventures sprinkled on over that. somewhere between a soapdrama and a gag strip and a traffic accident. Life. whatever. if you prefer to read it in spanish, check out 'las Aventuras de JONAS!' at http://jonas.subcultura.es/") # 263
add('Afrodays', 'http://afrodays.thecomicseries.com/', u'Inspired By Life Nope, nope turkeys') # 105
add('Albinobros', 'http://albinobros.thecomicseries.com/', u'Two guys at work shoot the breeze and do their best to not break the fourth wall.') # 109
add('Alittlebitofeverything', 'http://alittlebitofeverything.thecomicseries.com/', u"Gag-a-day comic featuring the adventures of Lucky, Swifty, their friends & family. Expect laughs, classic muscle cars, and stuff blowing up... but hopefully not the muscle cars. We don't have the budget to replace them.") # 791
add('Allthebbqsauce', 'http://allthebbqsauce.thecomicseries.com/', u'A comedy strip about antics and semantics.') # 125
add('Alone', 'http://Alone.thecomicseries.com/', u'One day when Arianna wakes up, something\xb4s different... The entire world is gone, she sets out on an exciting adventure to find out what\xb4s going on.') # 101
#add('Aloonaticstale', 'http://aloonaticstale.thecomicseries.com/', u"A king needs a team of elite experts to help fight crime and uphold the peace of Mercia. Unfortunately, he hires crazy people for the job. This didn't quite pan out the way he thought it would.") # 269
add('AmericanNerd', 'http://AmericanNerd.thecomicseries.com/', u"The adventures of the epynonymous nerd in Japan, going through the usual JRPG motions alongside a blonde amnesiac protagonist, a nature spirit, a Digital monster, a Sonic the Hedgehog cosplayer, and a few characters I haven't gotten around to yet. Whacky shennanigans ensue.") # 118
add('Americanextremists', 'http://americanextremists.thecomicseries.com/', u"Politics 'n stuff") # 490
add('Amtheatre', 'http://amtheatre.thecomicseries.com/', u"Do you like mid-low fantasy? Do you like comedy? Are you not offended by characters who are missing important appendages? Maybe you should read this. Or maybe not. Is this another DnD comic? No. But is it filled with cheap pop culture references? Hell no. Why is the main character a girl with no legs or right arm? Because I'm a sick human being, okay???") # 165
#add('Angelguardian', 'http://angel-guardian.thecomicseries.com/', u'Kyrsiel is a young apprentice of Guardian Angel. His teacher, Gersiel, is responsible he achieves a successful test mission to graduate. Moreover, Gersiel may not continue his evolution as Angel until Kyrsiel, who is his last student, graduates. And this is not easy! Both will play an important mission on Earth:: Protect Midori, a young student girl, from the demons that are chasing her. Will Kyrsiel do it successfully or will he fail again? Updates: Tuesdays and Fridays Story and drawings: \xa9 Reenave http://reenave.deviantart.com Translated into English by: Louise Brown http://cast-into-the-abyss.deviantart.com/') # 150
add('Angryfaerie', 'http://angryfaerie.thecomicseries.com/', u"Not all faeries are happy, cheerful little forest creatures. One, in fact, is downright ornery. She's mean-spirited, violent.. and ANGRY. Welcome to the twisted world of Angry Faerie.") # 475
add('Animangitis', 'http://animangitis.thecomicseries.com/', u'A parody of parodies, a gag of gags, a crossover that utterly abuses the term. This comic series and all its mini-plots points out those things that you just do not think about. Originally designed to be a crossover of different anime/manga characters and stereotypical situations, however now encompasses other subjects such as college life, snap shot scenes, math jokes, etc. It is very random...and you never know what (or who) is going to show up. Drawn in Vertical Manhwa style with varying detail/color. Usually updated Every Wednesday, Friday (temporarily on hold), and Sunday.') # 113
add('Antarcticbroadcasting', 'http://antarcticbroadcasting.thecomicseries.com/', u'Stickmen and their shenanigans-- inspired by life and other disasters.') # 129
add('Applepine', 'http://Applepine.thecomicseries.com/', u'Follow Applepine as he experiences life one problem at a time, with help from his friends of course! Each with their own way of solving the enigma of life, they help Applepine find his way through trouble, girls, and adventure in this ongoing series.') # 158
add('ArachnidGoddess', 'http://ArachnidGoddess.thecomicseries.com/', u"Dark modern fantasy! Born of a severe stroke of individuality & nihilism, 'Ahab' relates more to vermin & outcasts. Join the narrative as she abandons her humanity & finds herself in the gloom. Features peril, BDSM, & disturbing scenes.") # 612
#add('ArchportCityChronicles', 'http://ArchportCityChronicles.thecomicseries.com/', u"The best guessed center of the universe has an adventure for everyone...It's amazing what you can stumble into... Dissatisfied on what was supposed to be a fun trip it was only a matter of time until adventure lured Joe in. Now a group of discredited bounty hunters with a dangerous target have dragged him along for the ride.. Updates Tu and Thr... IF THE PAGES GO UP SIDE WAYS LET ME KNOW THE FILES SEEM TO BE MESSING UP FOR SOME REASON SOMETIMES!!! New opening is UP!!") # 200
add('Armybrat', 'http://armybrat.thecomicseries.com/', u'') # 127
add('Asperchu', 'http://asperchu.thecomicseries.com/', u"Welcome to the grand world of ASPERCHU, the electric/aspergers type hedgehog pokemon! Join ASPERCHU in his adventures to save Albville from the evils of evil villains of the PVCC and more. I am so greatful to have my TRUE and LOYAL fanbase, which I would never have had if not for the leadership and artistic genius shown to guide me by Christian Weston Chandler. I welcome all fans who wish to contribute to ASPERCHU'S adventures, as without them my power would be none!") # 568
add('Astralaves', 'http://astralaves.thecomicseries.com/', u'a comic I am working on. Sort of a fantasy thing.') # 131
add('Atm', 'http://atm.thecomicseries.com/', u'') # 180
add('Atowncalledalandale', 'http://atowncalledalandale.thecomicseries.com/', u"Leonard Smith is your average everyday loser, but during the full - moon becomes a hulking werewolf. Along with a Witch named Noa, and his perverted best friend Ron. Len must navigate everyday life and try to be as normal as possible. But that's easier said than done as he's living in the strangest town in the world. And in the town called Alandale, anything is possible.") # 246
#add('Augustos', 'http://augustos.thecomicseries.com/', u'When three kids escape from a shady research facility, where humans are being experimented on and dark deeds are happening unnoticed by the rest of the world, they find themselves in the middle of the desert, with no food, no water, and barely able to get along with each other. When their only friend in the world, Emily, is "kidnapped" by government officials, they boldly and stubbornly chase after her, hoping to find her as well as some clues about their past. But Emily is not all that she seems... On the way, they run into several strange and bizarre characters who rarely help and often cause more trouble for them. Augustos is a purely adventurous story with a bit of action and humor squeezed into it!') # 143
add('Awkwardshelby', 'http://awkwardshelby.thecomicseries.com/', u'This comic is a journal of my everyday life, an autobiography of sorts, that records my daily encounters and how I awkwardly react to them.') # 131
#add('BASO', 'http://BASO.thecomicseries.com/', u'An epic space opera') # 173
#add('BITCHSquad', 'http://BITCHSquad.thecomicseries.com/', u"BIOLOGICAL INDESTRUCTIBLE TACTICAL COMBAT HYBRID SQUAD If you like {sexy,sci-fi,alien,government conspiracy,action}, you'll love BITCH Squad. A group of teen friends expose to the world, the truth about a top secret government project combining alien DNA with human in an attempt to create super soldiers.") # 353
add('BTTF', 'http://BTTF.thecomicseries.com/', u'A man is residing in his home when he discovers that his fridge has vanished under mysterious circumstances. Updating Mondays, Wednesdays and Fridays.') # 146
#add('Barkingcrayon', 'http://barkingcrayon.thecomicseries.com/', u'Comics with a Conservative slant.') # 112
add('Baseballcapsandtiaras', 'http://Baseballcapsandtiaras.thecomicseries.com/', u'A tomboy, 16 year old Paige, and a girly girl, 8 year old Katie, discover a portal to a magical world in their house. The magical world is fraught with political dangers.') # 107
add('BattleoftheRobofemoids', 'http://Battle-of-the-Robofemoids.thecomicseries.com/', u'Robofemoids rocket off into space and meet up with lots of people who prove difficult to live with. Along the way they strip more for conversion and lovingly create more robofemoids and introduce the robohomoid.') # 191
#add('Beebleville', 'http://Beebleville.thecomicseries.com/', u"A cheesy webcomic following the odd perspective of one man's journey through work, marriage, fatherhood, life, death, and dealing with his wifes' damn cats interwoven with the strange happenings of the world we all inhabit.") # 154
add('Beepolice', 'http://beepolice.thecomicseries.com/', u'Bee Police is a comic about government conspiracies, mutant bees, mountain gods, ancient aliens, random monsters, and some aggies living in an out of the way town named Podunk.') # 202
add('BetaParticles', 'http://BetaParticles.thecomicseries.com/', u"This is where things go that don't go elsewhere. For those more curious as to my motives or rationale, see here: [url=http://betaparticles.thecomicseries.com/about/]Click this[/url]") # 323
add('BetweenRounds', 'http://Between-Rounds.thecomicseries.com/', u'') # 116
add('Biblebelt', 'http://biblebelt.thecomicseries.com/', u"I'm balancing a 3 1/2 year old on my head as I type this. Truly one of God's miracles. (The simultaneous balancing and typing, not my ability to reproduce.) Feel free to point out my spelling and grammar mistakes. Amen.") # 133
add('Bigfoldy', 'http://bigfoldy.thecomicseries.com/', u'The Big Foldy: A tale of friendship, robots, earth, lasers, space, action, comedy, sneezing, delicious food such as hot dogs and ice cream, laughter, incessant beeping, invasion, and the relationship between cultures?') # 145
add('BlueBloodHeroes', 'http://BlueBloodHeroes.thecomicseries.com/', u'Six children possess a genetic irregularity that grants them super-human powers and turns their blood blue. As criminals and injustice begin to rise in their hometown, they decide to form a superhero team.') # 199
add('Bobbythefetus', 'http://bobbythefetus.thecomicseries.com/', u"A fetal adventures of a fetus (which is not an e!). It features a Svalbardian/Swedish fetus(which might be a fetus, but isn't) named Bobby located somewhere in Iceland, adjustment disordered narrator who hates being seen, Roberta the fetus (who is not an e!) who is Bobby's girlfriend, the author himself, a sock puppet and a minor deity destined to ruin the world... This is a mirror of the DrunkDuck comic with the same name and author...") # 307
add('Booksdontworkhere', 'http://booksdontworkhere.thecomicseries.com/', u'A meta flavored webcomic with no 4th wall and a plot about a webcomic actress and the challenges she has to face. You know imaginary scripts, unreliable narrators, plot holes, meta walls, wacky physics, mad science, and budget cuts. Updates Monday, Wednesday, and Friday.') # 173
add('Boritom', 'http://boritom.thecomicseries.com/', u'The scintillating adventures of an alien, a redneck and a floating orb of death in the bucolic setting of fictional "Utopia Dell, Arizona." The strips currently running are all of the "classic Boritom" adventures from the strip\'s original run from 2000 to 2006. In all, there were about 325 strips, so I am currently updating 5 days a week in order to get people caught up. As we get closer to the "Big Day," where brand new strips start coming up, there will be lots of information and ballyhoo letting everyone know what to expect... to an extent. Spoilers, Doctor... Spoilers...') # 133
add('Brickland', 'http://brickland.thecomicseries.com/', u'Tales of Brickland centers around four groups of people: Kristy and Drew (adventurers who traveled to another continent for, well, adventures), Gina (a ninja), Captain Slade and his pirate crew, and Queen Toshiko, returned from the dead and bent on world domination. Again. A silly fantasy comic told with minifigs and bricks that updates every Monday, Wednesday, and Friday.') # 252
add('BrokenReality', 'http://BrokenReality.thecomicseries.com/', u'This story revolves around two teenage boys who suddenly find themselves living in japan for no apparent reason. Joined by twin Japanese girls, The four of them now seem to be living their lives in a world where the rules of reality are constantly being broken in one way or another.') # 105
#add('Bulletproof', 'http://bulletproof.thecomicseries.com/', u'In Junction City, there are men and women with strange powers and abilities, the Omega Humans. Ostracized by society, many turn to crime, while a few are employed by JCORP to keep the city safe. But can a corporation be trusted with law enforcement? Bulletproof is a B&W superhero comic set in a dystopian near-future city.') # 114
add('Bustysolar', 'http://bustysolar.thecomicseries.com/', u'The space adventures of Busty Solar and her space police team. Lots of strange jokes and naughty fun.') # 201
add('Cannonadeofhogwash', 'http://cannonadeofhogwash.thecomicseries.com/', u'As the title suggests, this is a cannonade of hogwash. Updated almost daily.') # 851
add('CatHero', 'http://CatHero.thecomicseries.com/', u"Cat Hero's epic Catventures as an Hero, starring Cat Hero as Cat Hero, by Cat Hero; is a graphical representation of the (mis)adventures of a cat-person named Cat Hero, whose arch-nemesis is CatoreH, a life-sized cardboard cutout of a (very) badly drawn cat-person. Half a quick comic, half an experiment to see if single-panel gag-a-day style can actually convey a story, and be good doing it.") # 539
#add('Cataclysm', 'http://cataclysm.thecomicseries.com/', u'Set on the last remaining hospitable island on a frozen world, a covert faction known as Militia attempts to overthrow a utopian civilization and their benevolent rulers, The Council.') # 409
add('Cautionarytales', 'http://cautionarytales.thecomicseries.com/', u'A webcomic, caution sign style.') # 101
add('Chocolava', 'http://chocolava.thecomicseries.com/', u'An awesome webcomic by The BIG Four (email: chocolavacomics[at]gmail[dot]com)') # 103
add('ChristianHumberReloaded', 'http://ChristianHumberReloaded.thecomicseries.com/', u"Once upon a time, an unpopular kid in a boarding school had his anime taken away and he turned to writing. He created what is simultaneously the worst and the best story ever created. This is that story's comic-book interpretation. You have been warned. Christian Humber Reloaded rips off/steals from every video game and anime ever made. Yes, even that one. It also has Bionicles. And Hitler. And it's supposed to be serious.") # 186
add('Chroniclesofloth', 'http://chroniclesofloth.thecomicseries.com/', u'The travels of a female adventurer in a world where her people are hated and her story of gaining friends and saving the world.') # 291
add('ChronoRedux', 'http://ChronoRedux.thecomicseries.com/', u'Chrono Redux is a retelling of the classic Chrono Trigger game, except that it makes fun of it. Truthfully, I mock it because I love it.') # 357
#add('Clockworkatrium', 'http://clockworkatrium.thecomicseries.com/', u'In a misguided attempt to develop their full potential for success, students at a German university are forced to participate in a campus chess "game" in which they are the pieces and the captures could consist of murder. (this is a mirror)') # 117
add('CoftheA', 'http://CoftheA.thecomicseries.com/', u'It is a fantasy comic that is loosely about philosophy. It features real pictures and a disturbing amount of software effects to create a drawn feel. Sadly I think it would be less work to just draw it. The main character, Jim Towers" is played by me and represents some sort of mental condition as the majority of the humour in the comic is the character played by me, calling out snarky remarks to me... the author/narrator. Hope you enjoy. Updates are every Friday for now.') # 101
add('Comingapartments', 'http://comingapartments.thecomicseries.com/', u'Apartment life is never an adventures. But J.B. and Diri are sure as hell gonna try to make it one.') # 116
add('Compozerz', 'http://compozerz.thecomicseries.com/', u'The Compozerz is the story of five classical composers from the 17-1800s, who find themselves whisked suddenly into the 21st century. The Guys have no idea why or how this happened, and to top things off, they find themselves stranded in the middle of the North American Desert. Frightened and confused, The Boys must figure out where they are and find out some answers. They end up stumbling upon a truck stop/diner and meet the free-spirited "hippie" chick, Connie Sanderson, who ends up \'adopting\' the Guys. So here unfolds the tale of Time Traveling Musicians Johannes "Joe" Brahms, Felix Mendelssohn, Frederic "Freddie" Chopin, Wolfgang "Wolfie" Mozart, Ludwig Van Beethoven and of course, Miss Sanderson (who must have some pretty incredible patience). Connie is not-so-loosely based on the author of the comic, by the way.') # 102
add('Conplicated', 'http://Conplicated.thecomicseries.com/', u'When sarcastic but charitable Amber Pennicastle follows a handsome panhandler to his secret hideaway, her life turns upside-down in this action/romantic comedy. (Revised and color version of Geode Corner).') # 161
add('Copypasteandmrbenjy', 'http://copypasteandmrbenjy.thecomicseries.com/', u'Copying and pasting characters with wacky hijinks! HI-LARTY ENSUES!') # 143
#add('Cowtoon', 'http://cowtoon.thecomicseries.com/', u'A crazy look into the lives of insane farm animals.') # 466
add('Crawlers', 'http://crawlers.thecomicseries.com/', u"Their fate is determined by dice and a set of laws they have become the masters of manipulating. Updated every Tuesday and Thursday at 10AM central time (except during campaign season because I'm running for the Missouri House of Representatives).") # 242
add('Crowbars', 'http://Crowbars.thecomicseries.com/', u'T-Shirts and other pointless merchandise also available on website.') # 116
add('Cubecows', 'http://cubecows.thecomicseries.com/', u'Cube Cows for everyone! Merely shout something out and I, your ever faithful servant, shall warp and twist it into a cube cow. Be it a character, idea, game, object, or even yourself, once put into the cube-cowifier, it shall be done! All suggestions are put on a list, and then selected randomly off of that list. If you or one of your characters are used, you have equal rights, and may use the drawing for personal purposes (eg. Avatar, displaying in webcomic...)') # 151
add('Cupcakegraffiti', 'http://cupcakegraffiti.thecomicseries.com/', u'The many adventures of Mr. Cupcake. Shop for Cupcake Graffiti on ETSY!! http://www.etsy.com/shop/sodapopcomics') # 252
add('DRouggs', 'http://dRouggs.thecomicseries.com/', u'Dark and wierd comic, but sometimes quite funny. [No storyline]') # 105
add('Dailydoodle', 'http://dailydoodle.thecomicseries.com/', u'A collection of doodles and drawings') # 442
add('Damnhipsters', 'http://damnhipsters.thecomicseries.com/', u"There's some in every generation... those that are so obsessed with being cool they'll do anything to keep ahead of the mainstream no matter how stupid it makes them look. These are their stories.") # 107
add('Datachasers', 'http://Datachasers.thecomicseries.com/', u'Data Chasers is set in the distant future, in a world still recovering from an apocalypse. In it, humans and androids live side-by-side and face the hazards of their dangerous environment. Though set far into our future, it reflects our past and our present, dealing with the politics and cultures of different people, along with touching on the very fundamentals of humanity. ( Updates Monday though Friday ) ( discription by Ranger_Brian_New! )') # 918
#add('Ddsr', 'http://ddsr.thecomicseries.com/', u'A sprite comic that has no Sonic sprites! Seriously, all custom done. Join two friends and there crazy adventures involving demons, robots, explosions and shiny things.') # 460
#add('DeadFingers', 'http://DeadFingers.thecomicseries.com/', u"Deadfingers is a story about an indigenous girl and her tribe, struggling to salvage its independence from the imperialistic mainland. Features magic, knife fights, guns, robots and everything else you'll find in the alternate universe. To read the entire comic (over 200 pages long and counting) Please visit http://www.drunkduck.com/DeadFingers/. DeadFingers updates with new pages every M T W TH F and S.") # 228
add('Deadducks', 'http://deadducks.thecomicseries.com/', u'Danny duck and his two brothers just moved in with their uncle in a small town full of ghost monsters and serial killers') # 151
#add('Demoneater', 'http://Demoneater.thecomicseries.com/', u'The grotesque life story of Saturno, a demon that eats other demons to get stronger.') # 620
add('Dictatorship', 'http://dictatorship.thecomicseries.com/', u'Meet mr. President and his wacky lackeys who rule the Republic of Syrania with an iron fist.') # 121
add('Doffeellende', 'http://doffeellende.thecomicseries.com/', u'') # 185
add('Donutsforsharks', 'http://Donutsforsharks.thecomicseries.com/', u'Donuts for Sharks is a bi-weekly comic about a vertically challenged Grim Reaper as well as the darkly absurd and quirky world going on around him. Comics Tuesday and Friday.') # 172
add('Doublejump', 'http://doublejump.thecomicseries.com/', u'Every day, I have a free half hour, and what better way to spend it than to sketch up some Videogame Comics super-quick for you guys?') # 161
add('Dragoncity', 'http://dragoncity.thecomicseries.com/', u'Millions of years ago, a comet wiped out the dinosaurs, but the dragons who were living along side them went underground and stayed there. And now we see the civilization that has come about from those refuges in a current day story.') # 1044
#add('Dragonet', 'http://dragonet.thecomicseries.com/', u'A wizard tries to raise an orphaned dragon in an age of war, evil, and magic. He soon finds out a dragon does whatever it wants...and he may make all the difference.') # 331
add('Drettaville', 'http://drettaville.thecomicseries.com/', u"Rook's life is thrown into chaos when he's suddenly put in charge of raising a seven-year-old daughter he never knew he had. A daily family-friendly comic strip!") # 374
add('Drifting', 'http://Drifting.thecomicseries.com/', u'A story of a Young "Drifter" named Venture and the mysteries of Auncen and Novossa.') # 103
#add('Dungeonhordes', 'http://dungeonhordes.thecomicseries.com/', u'In 1986 Dungeon Hordes was released on the Playtendo and moved 1 million units world wide which is way more successful than its previous release on the Batari 2200 in 1979. Now in 2011 Dungeon Hordes has returned bigger and better than ever with mind numbing graphics and all new enemies to fight. So how do the characters in game feel about this? Only time will tell. Enter the lives of Tiggz and Tomes, two level 5 bosses tired of being easily killed by player 1 and wanting the glory of finally becoming more than just petty bandits. Will they survive the new creatures that the mighty programmers have added to the game? Will they ever kill player 1 and move up the mob boss ladder? Will they ever get a raise from their uptight dungeon boss Kalakis and finally pay off their ale tabs at the Stinky Dragon Inn? Stay tuned and find out..... Will be updated Every Day!') # 451
add('EMT', 'http://eMT.thecomicseries.com/', u"an experiment in Mental Theatre, externalized in comic form. Now updating 3 times weekly, every M-W-F. [i]It doesn't serve the 3 fetish as well every 3rd day on dates divisible by 3 did, but you get more story for your money - with 3 more strips every month![/i]") # 165
#add('Educomix', 'http://educomix.thecomicseries.com/', u'A parody educational comic about a young man called Dave and his crazy adventures. "Good. I\'ll make toast."') # 256
add('Eightbitadventures', 'http://eightbitadventures.thecomicseries.com/', u"It's a sprite comic about Captain A, a robot built by Dr. Light. Set in the Mega Man universe but has very little to do with Mega Man, so you WON'T find any terrible recolors or anything like that. Just heavy edits provided by me.") # 107
add('Elektroanthology', 'http://elektroanthology.thecomicseries.com/', u'These are various unrelated comics I have worked on. Everything\'s tagged just in case. They\'re mostly short stories I\'ve done for different anthologies (Copyright also for "Various" because some of these I worked on with someone else as well). Updates whenever.') # 143
add('EternityC', 'http://EternityC.thecomicseries.com/', u'When a compulsion is so strong that it runs your life, you have a complex. When that complex centers around Eternity, you have an adventure. Join Fae as she searches for Eternity and all that it might bring her.') # 214
add('Everydayabnormal', 'http://everydayabnormal.thecomicseries.com/', u"When supernatural, technological, or mythic threats endanger human lives, only the Agency of the Unnatural can rise up to stop them -- but it's the ordinary people who are caught in the crossfire. Jon Grasseschi's ongoing saga explores how people react, live, and just survive when the unexplainable, the impossible, and the just plain weird intrude on their lives.") # 190
add('Fairydust', 'http://fairydust.thecomicseries.com/', u"A world where fantasy creatures are real ought to feel a little complicated. Should you want to visit it, start with the cities, they're full of humans and modern comfort, if you don't mind having a leprechaun for neighbour or a troll driver. But you're not a racist, right?") # 143
add('Fathead', 'http://fathead.thecomicseries.com/', u'A comic about wacky adventures, talking fruit and pointless conversations!') # 212
add('Felicity', 'http://felicity.thecomicseries.com/', u'Set in a futuristic New York City, a division of extreme motor-sport known as Mort-Racing gives prisoners a chance to fight for their freedom.') # 104
add('FireBorn2', 'http://FireBorn2.thecomicseries.com/', u'The King of the Dead, The Lord of the Shadows, and the Devourer of Souls are amassing their armies to take revenge against the world and the gods that have shunned them. Men and women from different walks of life will join forces to fight them.') # 188
add('Flickwit', 'http://flickwit.thecomicseries.com/', u"What's to know? A ragtag bunch of adventurers are embroiled in an Illithid's nefarious plot, and have to fight their way through hordes of monsters, escape the dungeon and save the local peasantry before the lot of them get vaporised in a dimensional cataclysm. You know-- the usual fare. Thrills, spills and fun for the whole family! Warning: Art quality varies wildly.") # 121
add('Foxtales', 'http://Foxtales.thecomicseries.com/', u'A manga based on faerie folklore. After encountering a man who can change into a fox, a girl finds herself mixed up in a world of faeries and mythical creatures.') # 103
add('Fpk', 'http://fpk.thecomicseries.com/', u'Imagine those badly-photocopied zines that were left on the tables at your local coffee shop got a shave and a haircut, finished their fine arts degrees, and turned out to have really odd Monty Python-esque senses of humor. Then they got married and had a kid. That kid is FPK.') # 485
add('Fraternit', 'http://fraterni-t.thecomicseries.com/', u"A comic strip about life, love, long-lost brothers, and everything else a high school girl has to deal with! THIS COMIC STRIP IS SEMI-AUTOBIOGRAPHICAL, WHICH MEANS MOST OF IT IS BASED ON THE IMAGINATION OF THE AUTHOR. ANY CHARACTERS THAT MAY BE BASED ON REAL PEOPLE HAVE HAD THEIR NAMES CHANGED. Special thanks to Jimmy Gownley, author of Amelia Rules! and cofounder of Kids Love Comics. Also, thanks to Bill Wahl, Nikki, my parents and friends. I couldn't have done it without you!") # 135
add('Freakingawfulpuns', 'http://freakingawfulpuns.thecomicseries.com/', u'FAP is a most of the time very random, somewhat poorly drawn, and sometimes political webcomic. Check us out on Facebook! [url]http://www.facebook.com/pages/Freaking-Awful-Puns-Webcomic/189101684454482[/url] "Laim is pretty cool I guess" -DSW "It can be funny enough to get suscribers" -MattWL "a quasi-ripoff of Cyanide and Happiness" -MrWeatherby "In general your site design is good... Thank you for letting me review your comic." -Bill Kloppenburg "You get nothing! You lose! Good day sir!" -Willy Wonka') # 169
add('Friendshipisdragons', 'http://friendshipisdragons.thecomicseries.com/', u"A screencap comic of My Little Pony: Friendship is Magic. Equestria is a custom campaign setting for Dungeons and Dragons, and the mane six are Player Characters. How will a party of six roleplayers fare in a world where the usual hack-'n'-slash high fantasy has been replaced by pastel-colored ponies?") # 252
add('Frontier2170', 'http://frontier2170.thecomicseries.com/', u"Life as an independent spaceship crew isn't easy. In addition to the astronomical cost of fuel, supplies and repairs, it seems like the big corporate outfits get all the well-paying jobs, leaving the petty runs they don't want to people like you. Those jobs don't pay well enough to make ends meet, and there never seem to be enough of them, so sometimes you have to break the law to put fuel in the tanks and food on the table. If that wasn't bad enough, there's a war going on, and that means cargo inspections and surveillance...") # 219
add('Fullmetalbrothers', 'http://fullmetalbrothers.thecomicseries.com/', u'') # 106
#add('Fusion', 'http://fusion.thecomicseries.com/', u"What's inside the pages of this little book isn't so much a comic as it is a viewport into another dimension where you can follow Savunn's hectic life as a Cambodian teen (and superhero fan-gal) as she tries her best to make her mark as her world's newest superhero, Fusion! As reader, you will serve as her confidant as you watch the reality show of her life unfold with each turn of the page.") # 193
add('Fuzzballandscuzzball', 'http://fuzzballandscuzzball.thecomicseries.com/', u'Fuzzball and Scuzzball are brothers who live in the gritty urban hell that is Happy City, New Jersey. They founded their own detective agency, and seldom have clients. These are their antics.') # 128
add('Fuzzylittleninjas', 'http://fuzzylittleninjas.thecomicseries.com/', u'Welcome everyone, Fuzzy Lil Ninjas Proudly Presents Shades of Gray. Updates to the Web comic on every Sunday. Please Click on the Latest Tab to see the most Recent Comic, Enjoy.') # 100
add('Galbertofbruges', 'http://galbertofbruges.thecomicseries.com/', u'A comic based on the book "The Murder of Charles the Good, Count of Flanders"') # 151
add('GalleryOfFreaks', 'http://GalleryOfFreaks.thecomicseries.com/', u'') # 404
add('Glomshire', 'http://Glomshire.thecomicseries.com/', u"The misadventures of the inhabitants of Glomshire, a medieval(ish)land of undetermined origin. LEGO\xae is a trademark of the LEGO Group, which does not sponsor, authorize or endorse this comic (and we don't blame them!)") # 413
add('Godhatesdads', 'http://godhatesdads.thecomicseries.com/', u'my journal comic or something. showing the good times and the bad times of being a weirdo in my mid 20s.') # 137
add('GodsAlmighty', 'http://GodsAlmighty.thecomicseries.com/', u'A comic that chronicles the strange events and imaginary happenings surrounding Bethany. Accompanying her in her day-to-day life and occasional flights of fantasy are the two Norse Gods, Freyr and Loki. If you like rainbows, sparkly things, the occasional narwhal, cookies, cakes and sexual innuendo (inYOURendo) Then by Odin, this is the comic for you. GOD DAMN I LOVE CHICKEN.') # 147
add('GreenEyes', 'http://GreenEyes.thecomicseries.com/', u'One page comics on the simple things in life.') # 142
add('GreenerGrass', 'http://GreenerGrass.thecomicseries.com/', u'This is the story of three strangers (and their pets), who for unknown reasons get dragged into a different dimension, named by them as the Grass-Green-Land. Whatever will await them there? Warning: This comic involves a lot of swearing. Updates whenever I have the time for it.') # 138
add('HIRI', 'http://HIRI.thecomicseries.com/', u"Autobiographical comic that's at least 80% true") # 113
add('Halloween2012', 'http://halloween2012.thecomicseries.com/', u'This is the Webcomic Hub for the multi-webcomic event known as The Halloween Cameo Caper 2012. The strips will be posted here as they appear on the main sites by the various authors participating in the event, however, here a sense of continuity will hopefully appear as the strips are being rearranged along the way.') # 119
add('Heavylittlepeople', 'http://heavylittlepeople.thecomicseries.com/', u'A (mostly) daily snapshot of the lives of these odd Heavy Little People') # 294
add('HitmanPiranha', 'http://HitmanPiranha.thecomicseries.com/', u'') # 102
add('Hodgemosh', 'http://hodgemosh.thecomicseries.com/', u"It's just kind of stuff. And then there's other stuff, and that's pretty much how it goes.") # 166
#add('Holon', 'http://holon.thecomicseries.com/', u'In 3013, mankind has been driven to the edge of extinction in an intergalactic war. The lifeline of their endangered civilization are HOLONs, space stations established to harvest omnipotent and extremely destructive particles...') # 186
add('Honeyvenom', 'http://honeyvenom.thecomicseries.com/', u'Honey Venom, the sweetest poison, the daughter of darkness. Honey is an adventurer with an obscure past. She is an assassin and a witch. This comic is about her adventures in mysterious lands, about her loves and her fights against revenants, vampires, evil priests, corrupted zealots, depraved ogres and other revolting villains. Feel you free to contact me at my email address: I like to talk about my comics and to make friends with those who read my works, as well with other comic makers.') # 277
add('HourlyComic', 'http://HourlyComic.thecomicseries.com/', u'A journal comic done once an hour and posted at a 24 hour delay. The updating schedule is in a constant state of flux. There will be maybe a hundred updates a week for one week, and then none for a long time. This comic not meant to be followed, but read. It should be noted that John Campbell is the pioneer of this idea.') # 205
add('Housepets1x', 'http://housepets1x.thecomicseries.com/', u'A new weird family approach! Primo is a talented actor, Spike is an avenger. Together they form the most caotic and crazy squad ever! Updates on Monday, Wednesday and Friday') # 257
add('Idonteven', 'http://Idonteven.thecomicseries.com/', u"A little 'slice of life'. Just about living as a college student, trying to learn to be social, random encounters around campus, little jokes, all that good stuff. Sometimes vaguely amusing things happen...Updated whenever") # 105
add('Ignitionzero', 'http://ignitionzero.thecomicseries.com/', u"Four years ago, Robbie Finch met his best friend on the Internet. Now he's off to college in that very friend's home town--well, city. Big city. Orson and his friends are exactly the kind of people Robbie wants to meet: punks, hipsters, queers, and artists like himself. It's their exploits that push him headfirst into a new kind of reality, one where the Fair Folk and humanity meet. The city of Glory is full of well-kept secrets, but they might just unravel them all.") # 185
add('Insanitycorp', 'http://insanitycorp.thecomicseries.com/', u'The new and improved--yet still not corporate--Insanity Corp is back with more panels and fewer sticks! :D [Reality not included, offer not available in the Neptunian quadrant, see inside for details.]') # 159
add('Isb', 'http://isb.thecomicseries.com/', u"Internet Superbuddies is an experiment in chaos theory, pixels, and utter fucking boredom. It features five protagonists who basically swear and hate each other and are in some kind of bizarre and unclear living situation, to where they also break the fourth wall and realize they're part of a grander machination of being in an experiment in chaos theory, pixels, and utter fucking boredom. It used to be based on real life. Then people started getting killed and orcs with intent to rape started showing up. Then things got wacky.") # 181
add('Its', 'http://its.thecomicseries.com/', u'The year is 2180. Immortality is now a commonly-available genetic modification, but complete unkillability has yet to be achieved... Or so the universe thinks. A single batch of military-grade prototype GELFs (Genetically Engineered Life Forms) has exhibited this ability, but at the cost of being rendered mentally unfit for military life. Cooped up for a year, the GELFs manage to escape from the facility that made them. Being a terrible pilot, one GELF, codenamed "Yellow", crash-lands its escape craft on the swamp planet of Bloogis V. After getting stuck in the swamp, Yellow is rescued by two employees from a refueling station orbiting Bloogis. With no ship, no money, and nowhere to turn, Yellow makes up a new name and a gender for itself, re-dyes its fur, and asks for a job on board the station. A couple weeks later, and Yellow, now known as Chaz, is already getting the hang of his job, mixing drinks, talking with customers, the works. What kinds of weird and wonderful customers will he meet while working at the Intergalactic Truckstop? (The comic doesn\'t have a lot of mature language, but there\'s a swear here and there so I figured I\'d play it safe!)') # 213
add('Itscomplicated', 'http://itscomplicated.thecomicseries.com/', u'The exploits of a city girl as she gets through her late teenage years') # 580
add('Jamiejupiter', 'http://jamiejupiter.thecomicseries.com/', u'Jamie Jupiter is a member of the Galactic Squadron-a team of intergalactic "space cops" who help protect the galaxy. After tracking a villain to Earth, she saves the lives of two teenagers and shares her secret with them. She now vows to use her cosmic superpowers to protect her new friends and her new home, while learning what planet Earth is all about. Monsters of all shapes and sizes threaten our way of life, but with a brave and determined alien; a deadpan snarker photographer, and her comic book-loving geeky boyfriend, no task is simple, and every day is an adventure.') # 169
add('JaysInternetFightClub', 'http://JaysInternetFightClub.thecomicseries.com/', u"A Bus Driver starts a female fight club in his basement, with his wife, and his wife's girl pals. They broadcast the fights over the internet, and sell the dvds of the matches.The cast goes through adventures outside of the club as well.") # 286
add('Jenfferscartoonphotomanipulaion', 'http://jenfferscartoonphotomanipulaion.thecomicseries.com/', u"where old , unanted lost photos gets a new life as a cartoon pin up for the cast of jenffer's show") # 218
add('Jenffersshow', 'http://jenffersshow.thecomicseries.com/', u'Welcome to New Wolf Creek in Yukon Canada. The new home of "Miss J and the AM." This strip is about Miss J and her rock band called "Miss J and the AM" and their life in New Wolf Creek. See, Miss J is a lesbian and just married Jenffer Jay, her friend . And that\'s only the start. Please note: There is some frontal nudity now') # 1330
#add('Jericho', 'http://Jericho.thecomicseries.com/', u"Jerry, a young women with depression and self esteem issues has had a rough time growing up, and all seems to be going well while she is at Bournemouth University studying Medical Science. However, after putting her fellow students health at risk while testing her new ultra sound glove in an attempt to find an alternative treatment for cancer patients, she is threatened with expulsion. Her tutor, Doctor Foster is soon to be threatened with similar actions after he is accused of having an intimate relation with one of his students. But Jerry's world is pushed to it's limits when her best friend Carl is diagnosed with an inoperable and very aggressive brain tumour. On top of all this, the media is constantly running a story about a serial killer who targets terminally ill patients. The odds are against Jerry, and she has to make a choice. Does she become the bad guy in order to save her friends life? Will she be able to help him before the killer strikes? And what has Doctor Foster done with her invention? 'Jericho' is due for release as a published/printed comic later this year, and this is your chance to read it first! Rather than going out and finding a test audience, we decided that the best test audience is the readers of Comicfury.com! Please rate and comment so that you can help us make a better comic reading experience for you! Thank you! Jericho is registered with the UK Copyright service. Registration No. 324507") # 151
#add('Jix', 'http://Jix.thecomicseries.com/', u'An alien sent to survey Earth for conquering crash lands on Earth and an alternate personality takes over and moves in with a 20-something year old woman. These are their stories. BOM BOM!') # 893
add('Judgedred', 'http://judgedred.thecomicseries.com/', u"A Modern Day Re-Imaging of A Syndicated Comic Strip You've Likely never heard of before. All Original artwork by Alex Graham/Michael Martin.") # 166
add('Jump2', 'http://Jump2.thecomicseries.com/', u'A demon possessed killer gets a glimpse of what life could be like free from his Master...but freedom, like all things in life, is difficult to attain and even more difficult to maintain. (This is the remake of the original.)') # 102
add('JustPeachy', 'http://JustPeachy.thecomicseries.com/', u'"Just Peachy" is a cheeky serial comic strip featuring a small college town\'s generation of college alums who aren\'t giving up and growing old without a fight. Kids: don\'t let your parents fool you, this is exactly how they behave when they think you\'re not looking. Parents: don\'t try to act all dignified and deny it. Liar, liar, pants on fire. In fact, you\'re probably worse than this.') # 217
add('Kayandp', 'http://kayandp.thecomicseries.com/', u"Kay is a college student who's passions are music and the arts, which probably makes her wacky enough... but also there is her best friend - a skeleton no one else can see, named P.") # 239
add('Kirahitogame', 'http://kirahitogame.thecomicseries.com/', u"A simple game that started with Kira and mine OC's. Every even page is mine, and every odd is hers.") # 194
add('Knavesend', 'http://knavesend.thecomicseries.com/', u"Knave's End is a port town in a fantasy world, peopled by humans, orcs, elves, dwarves, halflings, and some odd types of goblins. It's a center of political and criminal intrigue where the criminals are nasty and some of the guards are even worse.") # 101
add('LORDDARKE', 'http://LORDDARKE.thecomicseries.com/', u'The adventures of a middle aged black widow spider and her friends. UPDATED RANDOMLY.') # 187
add('Laceyinvestigations', 'http://lacey-investigations.thecomicseries.com/', u'Online Detective comic') # 118
add('Laserbrigade', 'http://laserbrigade.thecomicseries.com/', u'An experimental comic about cyborgs, robots, and aliens. With lasers!') # 293
add('Lastcallcomic', 'http://lastcallcomic.thecomicseries.com/', u'Last Call, a Slice-of-life and Humor webcomic, focuses on a woman in her thirties, the antics of her husband and friends, and her conversations with her best friend at a local bar, who happens to be an alcoholic succubus.') # 260
#add('Latchkey', 'http://latchkey.thecomicseries.com/', u"Latchkey is a daily comic strip, and takes its cue from strips such as The Perishers, Calvin and Hobbes, and Peanuts. It's about a group of eccentric and vaguely defective kids who spend most of their time together.") # 141
add('Legendoflink', 'http://legendoflink.thecomicseries.com/', u"What happens when lightning hits the TV in the middle of Nintendo's classic Zelda game? Probably not this. Updates Tue/Thu/Sat.") # 513
#add('Lena', 'http://lena.thecomicseries.com/', u'The story of a girl and her interdimensional "friend".') # 149
add('Lethargicmisanthropy', 'http://lethargicmisanthropy.thecomicseries.com/', u'Please, do not get depressed after reading this comic. That is my job.') # 195
add('Lifeexplained', 'http://lifeexplained.thecomicseries.com/', u'What started as a humorous attempt to participate in "Everyone Draw Mohammed" day resulted in a weekly comic in which things are observed.') # 224
add('Lilheroartists', 'http://lilheroartists.thecomicseries.com/', u'') # 169
add('LiteBites', 'http://LiteBites.thecomicseries.com/', u'An anthology by various creators.') # 505
add('Littleblackdress', 'http://little-black-dress.thecomicseries.com/', u'They say a "little black dress" will get you anywhere. Dress it up\' dress it down. This one is very special. It will do a lot for you, even if it\'s not always exactly what you wanted.') # 108
add('Lola2', 'http://Lola2.thecomicseries.com/', u'Lola is the story of a sad, sad 13 (now 14) year old girl, who lives with her eccentric grandmother. After just entering junior high school, Lola begins to make new friends and go about life like every other normal kid...of course "normal" is relative.') # 756
add('Longhike', 'http://Longhike.thecomicseries.com/', u'Seven people, one dog, one long hike. By Isaac Glovinsky') # 162
add('Lp', 'http://lp.thecomicseries.com/', u"It's a manga about a college student gets drafted into the Spiritual War for souls as a Prophetess of God. She battles demons, devils,and still manages to make it to class on time. Has action, adventure, and shoujo humor with a Christian theme.") # 260
add('LunaStar', 'http://LunaStar.thecomicseries.com/', u'Sister comic to Datachasers. covering events that occured in the past...Updates are "scheduled" for tues and thur... maybe the occasional bonus :D') # 106
add('Lxgrpg', 'http://lxgrpg.thecomicseries.com/', u"A screen-capture comic taking the film 'The League of Extraordinary Gentlemen' into a tabletop roleplaying game. Note: I don't actually play tabletop RPG's, so most of what comes up in the strips are things I learned from other similar webcomics and certain RPG video games.") # 165
add('Magisa', 'http://mag-isa.thecomicseries.com/', u'A comic about a loner, an angel, and a psycho cult that shoots up a school.') # 584
#add('Mascara', 'http://Mascara.thecomicseries.com/', u"Addison Walker is a girl with natural style. She doesn't even wear makeup because she feels that brains are more important than looks. In fact, one of her closest friends is the smartest boy in school. But she has no clue that he has a strange alter ego\u2014as a makeup artist. When they meet, will it be a makeover disaster?") # 204
add('Matespt', 'http://matespt.thecomicseries.com/', u'As aventuras e desventuras das vidas de quatro amigos') # 179
add('Mayonakadensha', 'http://mayonakadensha.thecomicseries.com/', u'Hatsune Rondo a Japanese-British teenager, living in Japan of 2010, disenchanted by her uneventful life and neglecting mother. But when Hatsune accidentally misses the last train home and boards a mysterious train that arrives on the dot of midnight she finds herself whisked back to London of 1888. Here she meets an orphan named Tom, who reveals to her that he is a member of the Baker Street Irregulars, a group of street urchins hired to assist Sherlock Holmes where needed in his investigations. Hatsune joins Tom and his friends in the Irregulars to tackle the many criminals that London houses. But one criminal in particular has Hatsune and the whole of London in a stranglehold of terror. Jack the Ripper. Contains some moderate gore and blood, a few uses of strong language, non-explicit nudity and some mild sexual scenes Updates a volume (70-90 pages) a month.') # 1032
add('Merelymortal', 'http://merelymortal.thecomicseries.com/', u'A comic about life, death, and futility. Currently on indefinite hiatus. =(') # 105
add('Mightymeteorite', 'http://mightymeteorite.thecomicseries.com/', u"What would you do if you had superpowers? Would you use them to fight crime? Live your life normally? Michael Matthews is going to try to do both.... but it's not as easy as you think it will be") # 288
add('Mildlyamusing', 'http://mildlyamusing.thecomicseries.com/', u'A comic about life, happiness, and flights of fantasy.') # 143
add('Minarga', 'http://minarga.thecomicseries.com/', u"My longer-than-ever-anticipated Mass Effect fancomic, originally posted on deviantART, also available here. At the present time, I'm still working on the script, and will be posting first drafts of every chapter as I sketch them out. Finished pages will come when I've written the entire script and have layouts/rough drafts of all the pages. Again, just to cover all my bases, I do not own the Mass Effect universe; it's the creation of Bioware, and they own all the rights. I don't own a damn thing. More of my art is viewable at http://amethystsadachbia.deviantart.com/") # 248
add('Mischeif', 'http://Mischeif.thecomicseries.com/', u"//>LOADING INTERFACE;;;STOP RIGHT THERE READERS! You are about to enter a world of complete randomness and lack of plot! I have warned you before hand. Some of these events are real but if anything I'd be pulling your leg if I said I met a caveman who hunts ducks with spears.///END Tl;dr- This is the world of Mischeif. Welcome to random. And beware a random 1337 plz, I do have a life. Sorta. Oh! And don't forget to check out my facebook page! For heads up on Mischeif and other crazy things I get myself into. https://www.facebook.com/pages/Mischeif/267542906656329?fref=ts") # 115
add('MoaK', 'http://MoaK.thecomicseries.com/', u"Morgan was not having a good day. Her singer flounced; her basist, and brother, got a better offer; her drummer was blown up by a dragon-- Wait, what's a dragon doing in Chicago? And what's with the orcs with guns? Updates Tuesdays and Fridays, 3pm Chicago time (Currently a mirror from Drunk Duck. You can read it here, about a chapter behind, but with no delays for Writer's block and computer issues, or there for the current story, but with the occasional filler page/missed updates.)") # 205
add('MoizmadComix', 'http://MoizmadComix.thecomicseries.com/', u"Crack detective Riddick Q. Loss' never-ending quest to catch the villainous Sir Dimswitch in 1950's Vancouver.") # 251
add('Monstersoup', 'http://monstersoup.thecomicseries.com/', u'A group of misfit monsters are sentenced to live under the same roof--a castle belonging to mad scientist, who is serving his own sentence for unethical experiments. The real question is, can a hodgepodge group of monsters live under the same roof? (Some comedy, horror, and a little bit of everything else.)') # 122
add('Morningsquirtz', 'http://Morningsquirtz.thecomicseries.com/', u'A filthy Taffy swirl of gooey pun drenched fun.') # 104
add('Moths', 'http://moths.thecomicseries.com/', u'In an alternate American past, Aram and his family must cope with the tightening grip of cynical political forces, while trying to understand the threat of the mysterious giant moths.') # 135
add('Mushroomgo', 'http://mushroomgo.thecomicseries.com/', u'Go is a Toad that wakes up in a desert, and is picked up by sand pirates. Describing the rest of the plot would take too long. Basically, a drawn Super Mario comic with original characters, disconnected from any particular game.') # 138
add('Namcowars', 'http://namcowars.thecomicseries.com/', u'A battle of non-epic proportions! Andore has assembled five classic Namco armies to fight in a competition to prove which is the most powerful! Updates Tue/Thu/Sat.') # 197
#add('Negligence', 'http://negligence.thecomicseries.com/', u'Drannik and Lizzep are two kids who are not very well supervised. This leads them into some very crazy adventures. They and the people they meet also deal with their own personal demons along the way. Updated Mondays, Wednesdays, and Fridays (concluded)') # 518
add('Neighborscomic', 'http://neighborscomic.thecomicseries.com/', u'it revolves around three characters, each one representing the three great countries of north america. george (a bald eagle)represents the usa, paco(a golden eagle)represents mexico and nashie(a beaver)represents canada. together they will have many adventures.') # 491
add('NewAmerica', 'http://NewAmerica.thecomicseries.com/', u"The story of a dysfunctional family, the crumbling nation they've come to control, and the tragic events that gave them power.") # 376
add('Niotp', 'http://niotp.thecomicseries.com/', u"I am a cynical crack-fiction writer that knows people will believe two things: 1.what they want to believe. and 2.what they've read about someone else. The following is a matter of respect: All characters are Copyrighted, and have been registered with the Library of congress twice over. I have the nice green documents to prove it.These drawings are the exclusive property of Helen's L.O.T. and are the original works of their artists. Distribution of these works, or use of the works herein to construct a sign display or otherwise similar is forbidden without prior written permission or consent. To support the artist purchase Transient Pulse and/or related materials through http://www.helenslot.com Consider this your FBI Warning label of doom.") # 417
add('NoSongs', 'http://NoSongs.thecomicseries.com/', u'Neil Gaiman meets H.P. Lovecraft meets The Bold And The Beautiful! Join Hector, our undead hero, as he attempts to make some sense out his recent death and resurrection. Magic, mystery and mayhem! Updates Sat-Sun.') # 152
add('Notsinceyou', 'http://notsinceyou.thecomicseries.com/', u"Your Mirror is an indie rock band in crisis. Zoe, the band leader, isn't sure about her year-old relationship with the band's guitarist, Jenny. Jenny isn't sure if she loves Zoe, but she knows she loves playing in the band. And then tensions rise when the band's tour lands in the backyard of Zoe's high school boyfriend, Rex. Will the band survive one more concert, let alone the rest of the tour? NOT SINCE YOU is a photo webcomic written by Daniel Barlow and Keith Moriarty and starring Vermont's most exciting cartoonists. About the authors: - Daniel Barlow is the co-founder (with Colin Tedford) of the Trees & Hills comic group, a social cartooning organization in New England. With Trees & Hills, Barlow has co-published dozens of comics, including the anthologies SEEDS, SHELTER and WOODS. Barlow lives in Vermont, works in politics and photographs cemeteries. www.danielbarlow.com - Keith Moriarty is a musician and writer living in New Hampshire. That's all you need to know.") # 180
add('Ocarinaoftim', 'http://ocarinaoftim.thecomicseries.com/', u"Welcome to our world! It's strange, but a lot of fun! This reads right to left, in traditional manga style. We should warn you: if you are looking for a serious adventure..you may want to pick something else to read. Also...there is a bit of language. Not a lot of harsh language, but it is there.") # 106
add('Organizedmess', 'http://organizedmess.thecomicseries.com/', u"Organized Mess documents the everyday lives of 4 oddly familiar characters. Sometime's it's humorous...most of the time it's not.") # 124
add('Outferasmoke', 'http://outferasmoke.thecomicseries.com/', u'The long and rambling story of Joss, a snarky young woman, her confused and abused buddy Lee and their perky housemate, Carrie. Contains drug use, sex, mild violence, profanity and, occasionally, boobies. Updates Sundays and Thursdays.') # 389
add('Outletting', 'http://outletting.thecomicseries.com/', u"OutLetting is the first webcomic of Feeny, a professional writing student at York University. starting out as random peeks into Feeny's mind and everyday life as she percieves it, the webcomic has much potential. Names have been changed for the protection of prudey and privacy-loving friends.") # 151
#add('Pandemonium', 'http://Pandemonium.thecomicseries.com/', u'The random spewage of my mind') # 225
add('Paperstreamer', 'http://paperstreamer.thecomicseries.com/', u'A science fiction web comic loosely based on ongoing research and speculation regarding space elevators and alternative space launch methods. The story and images are composed in pulp fiction and noir styles, with some use of 3D models, but with informative sections regarding the related technologies and concepts. The author and artist is an active reader of related technical research papers and hopes to entertain the audience while learning about the space elevator and its related physics concepts.') # 124
add('ParaFrenic', 'http://ParaFrenic.thecomicseries.com/', u'ParaFrenic is an 18 year old half-man/half monster who holds down a daytime job as a video comic actor and spends the rest of his days trying to survive the tough avenues of Vagrant Street.') # 113
add('Patchworkpeople', 'http://patchworkpeople.thecomicseries.com/', u"The fungus changes people, and it makes them change themselves. Lets. Yes, it lets them change themselves. Lets. I know, I just said. Oh. do you mean with an apostrophe? Let's? Sure, whatever. Let's change things. Things are Changing.") # 156
#add('Pegwarmers', 'http://Pegwarmers.thecomicseries.com/', u"Pegwarmers is basically a rip off of Twisted Kaiju Theater, but with superhero action figures. Occasionally, Transformers, Godzilla, and Star Trek characters will make an appearance, but it's predominantly superhero based. The main three characters are Deadpool, Spider-Man, and Batman.") # 527
add('Perspectives', 'http://perspectives.thecomicseries.com/', u'The dark twin of humor. A webcomic all about points of view. I write this in my spare time at work to stay sane, and wanted to share it with the world. I update every Monday, Wednesday, and Friday.') # 216
add('Pitchblack', 'http://pitchblack.thecomicseries.com/', u'A black comedy webcomic with a particular tendency to make little kids cry.') # 191
add('PlasticBulletsMayhemUnloaded', 'http://PlasticBulletsMayhemUnloaded.thecomicseries.com/', u"Andrew Cross was going nowhere fast. It seemed that he couldn't stick to anything that he tried. However after several deaths in the family, Cross realized just how short life truly is. Determined to leave his mark on the world before he dies, Cross and his friends enter the Mayhem Unloaded tournament. A brutal combat simulator, where there can only be one victor.") # 100
add('PobrePucho', 'http://PobrePucho.thecomicseries.com/', u'There is a place far underground you have no idea it exists, with Lycanthropes, giant bugs, weird politics and NINJA BUNNIES. And poor Pucho just has to suck it up and join the party as the new Lycan in Paws Den!') # 258
add('Poharex', 'http://poharex.thecomicseries.com/', u'In a prehistoric world, Poharex rises up to become the defender of all dinosaurs.') # 220
add('Popcultureskids', 'http://pop-cultures-kids.thecomicseries.com/', u'A small group of kids, including a relative newcomer to the town, create a club for their mutual love of TV, music, movies, etc. My influences include Krazy Kat, Pogo, Bloom County and Calvin & Hobbes.') # 316
add('Poussiere', 'http://poussiere.thecomicseries.com/', u"Un monde o\xf9 les cr\xe9atures fantastiques existent ne peut qu'\xeatre un peu compliqu\xe9. Si vous voulez le visiter, commencez donc par les villes, c'est plein d'humains et de confort moderne, tant que \xe7a ne vous d\xe9range pas d'avoir un lutin pour voisin ou un troll pour chauffeur. Mais vous n'\xeates pas racistes, n'est-ce pas?") # 143
add('President', 'http://president.thecomicseries.com/', u'Wiola is a vampire, but not the classic one. Indeed, she is "Ethical Vampire": those vampires that resists to blood\'s thirst reliance and live their un-life as outcasts. With Wiola come her prot\xe9g\xe9, a young vampire who has not yet passed the stage of reliance to blood. To complicate things the young vampire can resist the addiction to blood only by being surrounded by potential victims, and this is why Wiola choose to bring him in the capital of Riave\xe9. Riave\xe9 is a nation destroyed by the last war, a place of lost memories of a mighty, now fallen, kingdom and ancient secrets never dug up. Riave\xe9 is the perfect place for ethical vampires like, silent creatures with no identity.') # 161
add('Presidente', 'http://presidente.thecomicseries.com/', u'Wiola \xe8 una vampira, ma molto differente dalla mitologia classica. Essa, infatti, \xe8 una "Vampira Etica": cio\xe8 quel gruppo di vampiri che resiste alla sete di sangue e viveno una simil-vita da emarginati. Con se Wiola porta un pupillo, un giovane vampiro che non ha ancora passato la fase di resistenza alla dipendenza del sangue. Data la natura complicata del passaggio il giovane vampiro potr\xe0 resistere alla dipendenza da sangue solo stando circondato da possibili vittime, cio\xe8 altri umani; a questo scopo viene scelta la capitale di Riave\xe9. Riave\xe9 \xe8 una nazione rasa al suolo nell\'ultima guerra, un posto grigio dove si \xe8 spenta la memoria di un potente regno, oramai decaduto, unito ai suoi antichi segreti mai rivangati. Riave\xe9 \xe8 il posto perfetto per silenti creature senza identit\xe0 come i vampiri etici Wiola e Dyudan') # 161
add('Princeofcats', 'http://princeofcats.thecomicseries.com/', u'') # 253
add('ProjectGTH', 'http://ProjectGTH.thecomicseries.com/', u'A story about a genetically engineered girl made to be a killing machine. Who now tries to live a normal life after escaping her creators, but is still haunted by her past') # 454
add('Prologue', 'http://prologue.devonlegacy.com/', u"Earth's fate is in the hands of 2 alien races! Luckily 1 of them isn't so bad. Attempting to stop a vicious horde can 2 specially gifted humans (Fenny & Sally) actually turn the tables of balance on this war? Year 2132 Fantasy, SciFi, Action, Adventure") # 274
add('Pulse', 'http://pulse.thecomicseries.com/', u'Annie "Pulse" Chang, and Tabitha "Bolt" Greene, two female human batteries become armored super-heroines.') # 119
add('Purehavoc', 'http://pure-havoc.thecomicseries.com/', u"Aaron Kidway is a 20 year old pizza delivery boy who hasn't had much luck in life...But Aaron's luck changes when Aaron meets a mysterious girl during a delivery!") # 117
add('Pushy', 'http://pushy.thecomicseries.com/', u"This comic follows the amazing adventures of Pushy and his cute family of candy colored chipmunks.join the adventure!anything can happen-and it will!sometimes it gets a little crazy,sometimes you won 't understand it-but you don't have to!it's all part of the adventure.Pushy combines my favorite shows into one! all characters are original! Pushy-Always Ridiculous/Always Amazing.") # 208
add('RPS', 'http://RPS.thecomicseries.com/', u'RPS follows the near asylum-level misadventures of the Role-Play Saturday LARP game. Updates Wednesdays!') # 178
add('Randomthoughts', 'http://randomthoughts.thecomicseries.com/', u"Yeah so this really is random thoughts. I woke up one morning thinking about a duck-sausage and I figured I might as well start doing a webcomic about things. Yes..Things. Stuff and junk and stuff that happens to me. And things. It's mostly sort of an online diary, except also not. It's just random thoughts. I apologize for dry humor, bad puns and possible injuries you suffer from facepalming. However, I hope you enjoy :D") # 116
add('Rangerrandom', 'http://rangerrandom.thecomicseries.com/', u'Basically, where I put my unrelated art, or art not important enough to be mentioned.') # 257
add('Rebels', 'http://Rebels.thecomicseries.com/', u'In a dystopian future, Humankind is embattled with a seemingly superior foe - with a weakness to Geurilla warfare. National armies (and the nations they once protected) have dissolved into anarchy or destruction (or both), and the story follows two former special operatives turned Geurillas, fighting back any way that they can.') # 122
add('RecklessComix', 'http://RecklessComix.thecomicseries.com/', u'We are a couple of guys (or a few sometimes) With a camera and too much free time at work... Enjoy us') # 166
add('Requiemsgate', 'http://requiemsgate.thecomicseries.com/', u'') # 155
add('Residentweirdo', 'http://residentweirdo.thecomicseries.com/', u'Some games, some life, some randomness. Monday updates') # 102
add('RumfAdventures', 'http://RumfAdventures.thecomicseries.com/', u"Hello! It is my pleasure to welcome you to the site of my beloved comic strip Rumf Adventures! In the event that you have not become acquainted with my tiny strip,allow me to give you a quick rundown.This is an action-packed adventure strip with a dash of humor.It features a cast of thousands, starring the mighty adventurer Rumfus! That's it.I don't want to spoil the rest for you,just start reading! Onward to Adventures!") # 128
add('Ryuskrew', 'http://ryuskrew.thecomicseries.com/', u"Ryu's Krew deals with a war between the Greek Gods and Loki, the Norse God of Trickery. It is up to the Soldiers of the Gods to defeat the Colossi and obtain the 12 keys needed to enter Loki's homeworld in order to save life as they know it.") # 133
add('STA', 'http://STA.thecomicseries.com/', u"When two worlds are threaten and all hope seems lost, one hero will stand. Sadly, that's the best They're going to get.") # 106
add('Sarakleeyo', 'http://sarakleeyo.thecomicseries.com/', u"A World of Warcraft themed web comic starring the Argent Crusade's unusual misfits. The crusade allowed heroes of the Alliance and Horde to become partners. Sara & Kleeyo set the example...provided they can survive their friendship. Updated weekly on Saturdays.") # 114
add('Savemegebus', 'http://savemegebus.thecomicseries.com/', u"Gebus considers himself the True Saviour of Humanity, though he rarely does anything about that. The comic revolves around him and his adventures which are often written as multiple-strip fabricated stories in order to explain changes in Gebus' appearance. As a comic straight out of the minds of the authors with little or no forethought, what plot or general continuity there is exists largely as an excuse for the authors to keep making comic strips. The fourth wall is broken regularly, and characters are taken directly from the authors' real life, though the storylines are not. The comic's style is taken from the comic it was spun from, Pixel-Sapiens, which features blocky characters with little to no curves or movement, and simple or absent backgrounds.") # 125
add('Sawbladersblacknuzlocke', 'http://sawbladersblacknuzlocke.thecomicseries.com/', u'*SADLY, THIS COMIC HAS BEEN ABANDONED. NO FURTHER UPDATES ARE BEING MADE TO THIS RUN.* A hand-drawn Nuzlocke comic detailing one crazy adventure in Pokemon: Black Version! Trust me, the art gets better as it goes along! Original Thread on the Offical Nuzlocke Forums: http://s7.zetaboards.com/Nuzlocke_Forum/topic/8520848/') # 409
add('Schizmatic', 'http://schizmatic.thecomicseries.com/', u'Schizmatic is a webcomic based on blueprint schematics applied to actual life. It puts the cosmos under a microscope, and reality under analysis.') # 232
add('Secondcrimeanwar', 'http://secondcrimeanwar.thecomicseries.com/', u'Set in Ukraine after the fall of the Soviet Union, in an alternate 1995, this is a story of civil war, terrorism, revolution, missing nuclear weapons, and some of the most disgusting sausages on the planet. Hang on tight and enjoy the ride! Updates every three days, on average, real life permitting.') # 248
add('Seconds', 'http://Seconds.thecomicseries.com/', u'All the comics here are primarily made in [i]Second Life[/i] and other virtual worlds, using crews of avatars to pose for and shoot the images used in each panel. It follows different stories with different characters over time. The initial story, [i]Return to Second Life[/i], is about what happens when avatars meet their owner in-world. General schedule is one page a day when reprinting , and about one page every two days when in production.') # 361
add('SeeYourFeels', 'http://SeeYourFeels.thecomicseries.com/', u'I have a thought or a feeling (or someone makes a clever comment) and I translate it into a single frame comic. This comic is not a continued story, so you can jump in anytime. Update Schedule: Every business day (Monday through Friday, excluding holidays) www.facebook.com/ICanSeeYourFeels') # 173
#add('Seed', 'http://Seed.thecomicseries.com/', u'A fantasy tale about three individuals in a time of war between two unlikely factions.') # 125
add('Serengetti', 'http://serengetti.thecomicseries.com/', u"Serengetti Dreams, as you may have inferred from the title, is a webcomic by Shane Itram. It updates daily, Monday through Friday. First time here? Kind of lost? Check out Dr. Bolton's welcome to new readers!") # 510
#add('Shades', 'http://shades.thecomicseries.com/', u'A WW2 fighter pilot, a First Century warrior queen and a prehistoric mystic. Oh, and their tailor. These are not your common-or-garden heroes!') # 189
add('Shadowsofnight', 'http://shadowsofnight.thecomicseries.com/', u'Shadows of Night is a dark depiction of the Spider-Man mythos, re-imagined in a universe where SpiderMan is more brutal and darker than ever.') # 100
add('Shatterrealm', 'http://shatterrealm.thecomicseries.com/', u'Iconoclasts clash as wanderers from parallel worlds fight for survival, meaning, and a way to get home. Through tehcnological or supernatural means, a random few have managed to move back and forth between worlds. Some are lost. Some are searching. Some are hunters and exterminators. An exploration of the human heart.') # 106
#add('Signifikat', 'http://signifikat.thecomicseries.com/', u'While on the run from the Cinnamon City authorities, robotic girl Sunhra meets her match at the outskirts of the information highway: a young man with the ability to bend machinery to his will...') # 149
add('SimplySarah', 'http://SimplySarah.thecomicseries.com/', u'Follow Sarah through her life as she deals with her own personal relationship issues and those of the people around her. Lesbian themed with one trans character and lots of other varied relationship issues.') # 127
#add('Sketchy', 'http://sketchy.thecomicseries.com/', u'Absurdly and charmingly absurd adventures that will make you say "Gosh!" Updates M-F.') # 454
#add('Slightlyaboveaverage', 'http://slightlyaboveaverage.thecomicseries.com/', u'Keiko Tachibana is an average High school girl. Scratch that. She\'s a self proclaimed "Slighty above average" High school girl who has dedicated herself to being only moderately better than the social norm. However one day she gets a visit from someone Way over the top. An inter dimensional cutie whom goes by the name Llla-Elac Ngtholi Cllegogg, also known as "Laila" to humans. She has come to destroy the sanity, and lives of everyone at Daisuke Ryuzaki high school. However, poor Keiko seems to be the only one at school whom has noticed this terrifying beast, and to make matters worse, she\'s staying at her house!! Will Keiko be driven insane by the ramblings of this terrible alien and her Slightly above average lifestyle tossed to the wind? Or will she succeed in defeating this strange alien menace!? Find out in this incredibly odd web comic inspired by the works of H.P. Lovecraft!') # 116
#add('SlipstreamSingularity', 'http://SlipstreamSingularity.thecomicseries.com/', u'350 years have passed since the first and only mission beyond Human Occupied Space was launched. In search of the alien intelligence that sent such wondrous knowledge back to Earth, the Odyssey mission was lost. Now, denied their own home world by the rebellion of their own children creations, the Synthetics, humanity has become a race of despots and wanderers that meander through the stars, eking out an existence. Updated Tuesdays and Saturdays. Created by TedChristensenGallery.com') # 168
add('Smalltownvalues', 'http://smalltownvalues.thecomicseries.com/', u'A mixed up family where at times, the pets have a better grasp of a situation than the humans.') # 131
add('SoFunnyIForgotToLaugh', 'http://SoFunnyIForgotToLaugh.thecomicseries.com/', u'One day, a neurotic artist decided to create a stick figure comic. Then God said, LET THERE BE CHARACTERS; then appeared Suds, a cynical drinking smartass, Perry, a shy guy lost in his thoughts, and Avital, the dumb creator herself. Together, they will overcome horrifying obstacles. Like CVS.') # 132
add('Sonichuredone', 'http://sonichuredone.thecomicseries.com/', u"Remember Sonichu? Well, start forgeting it, because Sonichu: RE-Done is here. An all new version of sonichu, made from obselete paint programs and cheap photoshops. Join Dash Sonichu and his friends as they journey through CWCville in adventures that involve beating up Jerkops, or trying to get rid of Chris. It's the first Sonichu comic made for multiple languages, so everyone can read the failtastic tales of Dash Sonichu. As of March 12, 2012, Chris-chan himself has, for some reason, declared this comic as an official Sonichu re-make. As of July 2012, Chris-chan has given the official Sonichu rights to Screws Enterprises, as he is soon to be shown in court on 10th July. As of December 20th 2012, Sonichu: RE-Done in English has been completed, and will no longer publish new adventures any time soon. Please check the blog for further updates...") # 542
add('Sonichuredonejapanese', 'http://sonichuredonejapanese.thecomicseries.com/', u'Japanese version Sonichu \u306e\u4e16\u754c\u3078\u3088\u3046\u3053\u305d \uff01\u3053\u306e\u5909\u66f4\u306e\u30d1\u30ed\u30c7\u30a3 CWC \u306e\u8584\u5f31\u6f2b\u753b\u306e\u304a\u697d\u3057\u307f\u304f\u3060\u3055\u3044\u3002(\u3059\u3079\u3066\u306e\u7ffb\u8a33\u306f\u30d3\u30f3\u30d3\u30f3\u7ffb\u8a33\u306b\u3088\u3063\u3066\u884c\u308f\u308c\u3066\u3044\u307e\u3059)\u66f4\u65b0\u30d7\u30ed\u30b0\u30e9\u30e0\u3001\u304a\u3088\u3073\u30e9\u30f3\u30c0\u30e0\u306a\u8a18\u4e8b\u306e\u305f\u3081\u306e\u30d6\u30ed\u30b0\u3092\u78ba\u8a8d\u3057\u3066\u304f\u3060\u3055\u3044\u3002 \u66f4\u65b0\u30d7\u30ed\u30b0\u30e9\u30e0: \u30b9\u30da\u30eb \u30df\u30b9\u767a\u751f\u3057\u307e\u3059\u3002') # 193
add('Sossaga', 'http://sossaga.thecomicseries.com/', u"Ages long forgotten, the celestial Goddess Alitheea felt betrayed by the creatures she had birthed and released devastating curses upon the worlds. Thus all trembled in fear... Hundreds of years since, and the worlds had yet seen a conclusion to the Goddess' calamities. Some sought to free themselves from the deity, some sought to dominate those weaker than them, and others simply wished to be left alone. The Seraph, the disinclined and untrained heroine, is given the daunting task of figuring out what had happened in the past that had set the stage for the upcoming era. Unable to comprehend her new life, she is constantly diminishing into anguish and hardship. With the protection of the Scions, the Seraph must fight to save the worlds, the persons she loves, and herself. So much for one teenage girl to do...") # 133
add('Spacefarmer', 'http://spacefarmer.thecomicseries.com/', u'') # 107
add('Spacefighters', 'http://Spacefighters.thecomicseries.com/', u'Do you like space men, martians, ray guns, talking chimps, katana blades, the legend of sasquatch, jet packs, teleportation, and the devil? ...If the answer is yes, than this comic is for you!') # 126
add('Spacepirates', 'http://spacepirates.thecomicseries.com/', u"In the near future, human colonies on Jupiter's moons are attacked by mysterious space pirates whose advanced ships can outrun other vessels. A mismatched handful of smugglers takes the pirates on, using near-obsolete hardware, and help from an unexpected source.") # 111
add('Spacepulp', 'http://spacepulp.thecomicseries.com/', u"Looks like I'm doin' a SPAAAACE PUUULLLP comic. Mostly for colorin' practice.") # 188
add('Spades', 'http://Spades.thecomicseries.com/', u"DISCONTINUED Spades is created by my proudly obnoxious teenage MonsterBrat with it's upkeep done by me. M.B. will referred to as 'it', by it's own request. We both play World of Warcraft as well as various offline games so alot of what is posted will reflect that and it's uncensored (shudder) creepiness. Eventually it will no longer be a teenager and I'll have to change this info thingy again. ~Rrayven") # 129
add('Spf1337', 'http://spf1337.thecomicseries.com/', u'A webcomic about the little things in life that let you get through the hard times. With groan-inducing puns and hilarious antics, SPF is here to entertain you. Or is it the other way around...?') # 168
add('Spooncomic', 'http://spooncomic.thecomicseries.com/', u'A evil wizard turned Charles\' whole town turned into a kitchen (that\'s right). Cursed with the body of a SPOON, he has embarked on a journey to find the wizard and along the way, he will meet other "cursed" ones.') # 268
add('Sscomic', 'http://ss-comic.thecomicseries.com/', u'') # 258
add('Stardustthecat', 'http://stardustthecat.thecomicseries.com/', u'Stardust the Cat is a comic about a cat and a mouse who watch TV and occasionally have adventures.') # 151
add('Starraccoon', 'http://starraccoon.thecomicseries.com/', u"it's bugs bunny meets spiderman an alien raccoon escapes to earth after a evil warlord destroys his planet now he's on run from the goverment the men in black alien bounty hunters and the warlord himself") # 165
#add('Stickfodder', 'http://stickfodder.thecomicseries.com/', u"Stick figures at their finest and not so finest. Jokes, violence and harsh language? HELL YEAH! It's just fun for the entire family.") # 327
add('StrangeAttractors', 'http://StrangeAttractors.thecomicseries.com/', u'Strange Attractors is a humorous post-modern retro-science fiction comic. Sophie, the curator of the vast Museum of Lost Things, becomes embroiled in an epoch spanning war between magic and science, in which the comics she loves are actually coded histories, and she\u2019s become a magnet for all sorts of cosmic weirdness.') # 100
add('Subjectm', 'http://subjectm.thecomicseries.com/', u"An alien is en route to Earth with a mission so mysterious that not even he is sure of what it is... except he does now and he's either about to die or be stuck on a planet until he figures out a way off of it.") # 109
add('Supershashi', 'http://supershashi.thecomicseries.com/', u'') # 102
add('TMAOTTPT', 'http://TMAOTTPT.thecomicseries.com/', u"Once upon a time, in a trailer park far, far away.. 3 misfit friends embark on a journey of semi-epic proportion that could change the course of their history!--and it's all told through Legos! *Updates every Monday, Wednesday, and Friday!*") # 202
add('Tangledmess', 'http://tangledmess.thecomicseries.com/', u"The journal comic of a young artist, who has no idea what she's doing in life, and that's okay by her.") # 127
add('Tba', 'http://tba.thecomicseries.com/', u'follows the daily life of four sisters and their friends in Tepes Broadview Apartments in Millwood, Iowa') # 215
add('Tdd', 'http://tdd.thecomicseries.com/', u"We like to ask questions. Questions like: What's the best way to flirt with that cute girl I always see around? Am I funny or just delusional? What about second breakfast? Is it possible to create a quality webcomic with little to no artistic ability? To all of these we say; let's find out! We hope you enjoy our work.") # 111
add('Tennisballman', 'http://tennisballman.thecomicseries.com/', u"He's a man of severe delusion. She's a girl with anger problems. He has a skull minion and a giant dirt-breathing fish. She has enemies waiting to be killed with gorey passion. Updated every Tuesday and Friday.") # 160
#add('TheDragonFistsofSmortySmythe', 'http://TheDragonFistsofSmortySmythe.thecomicseries.com/', u'A Martial Artist monk leaves his mountain monastery to take up a life in the outside world. Wishing for a peaceful existence, he instead becomes a reluctant hero, bodyguarding his intrepid, trouble-prone friends on their adventures.') # 453
add('TheFaithful', 'http://TheFaithful.thecomicseries.com/', u'Follow your favorite New England sports teams with Soxy: a Boston Red Sox Puppet worn by a crazy, anonymous fan of the Red Sox, Patriots, Bruins, and Celtics.') # 152
add('TheFunnyZone', 'http://TheFunnyZone.thecomicseries.com/', u'A Strange and Funny Dimension of Laughter, Wierdness, and pathos.') # 118
add('TheUnthinkableHybrid', 'http://TheUnthinkableHybrid.thecomicseries.com/', u"It's 1956... Betty Jo Carlson and her little brother, Johnny, have discovered an atomic monster prowling the lonely, desert canyon outside their small, California town. Along with their friends, Skip Walters, and the curmudgeonly Professor Willoughby, Jo and Johnny try to keep the monster out of trouble while weathering the suspicions and prejudices of Cold War America.") # 232
add('Thebestof25yearsofmissjandtheam', 'http://thebestof25yearsofmissjandtheam.thecomicseries.com/', u'The best from 25 years of "Miss J and the AM." This was my strip before I started doing "Jenffer\'s Show." It\'s all about \'Miss J and the AM,\' a rock band in a place called the Yukon.') # 273
add('Thebigscifimishmash', 'http://thebigsci-fimish-mash.thecomicseries.com/', u"this comic is a sci-fi comic which mixes several differnt sci-fi things into one. for instance, it starts off kind of like the hitch hiker's guide to the galaxy but quickly moves on to parodies of star trek, star wars and many more.") # 183
add('Theblackprincess', 'http://theblackprincess.thecomicseries.com/', u"While Wright as Rayne centers around Alex Rayne after his mind is put into the body of a teenage girl, The Black Princess follows the lives of two of the women responsible, Sareena Black and Misty Smid. The two are best friends as well as co-workers in Eighth Sin's Paranormal Division, their primary job being to study and at times stop unusual magic.") # 213
add('Thechroniclesofdrew', 'http://thechroniclesofdrew.thecomicseries.com/', u'A Biographical chronicle of the exploits of a majestic and ruggedly handsome man by the name of Drew. Join him through his exploits of life, love, laughter and the occasional bitchslap') # 124
add('Thedailyproblem', 'http://thedailyproblem.thecomicseries.com/', u'In November 2009 I started copying a bunch of people online who drew a comic about their lives every day. All of the stuff in these comics is true, all of the people are real, and some of it is even kind of interesting.') # 111
add('Theepicepic', 'http://theepicepic.thecomicseries.com/', u'The Epic Epic is an epic tale told with the Lego brick that updates on a Monday-Wednesday-Friday schedule.') # 155
add('Thegarden', 'http://thegarden.thecomicseries.com/', u'An evil angel, a silent demon, and an insanely happy girl who are forced to work together to complete a mission that none of them wanted.') # 198
add('Thelozoyas', 'http://thelozoyas.thecomicseries.com/', u"It's 1997, Jack Lozoya is 21 and finally on his own when his mother dumps his 7-year old little half-brother, Max, on his doorstep without even confronting him. He later finds out their mother cannot afford to take care of Max since his father died, leaving her nothing to live off of. Now Jack is stuck with the responsibility of a single father, so soon after moving into his own place no less!") # 173
add('Themates', 'http://themates.thecomicseries.com/', u'The random events in the random lives of four friends') # 180
#add('Themitchelleffect', 'http://themitchelleffect.thecomicseries.com/', u'A typical tale of an ordinary teenager who accidentally summons a demon that eats all his snacks and smokes all his good weed. You know.....a classic :) If you like what you see here come friend me on Facebook for more goodies and funny content: Cornelius Goodfellar') # 124
#add('Thepiratebalthasar', 'http://thepiratebalthasar.thecomicseries.com/', u'Wilson Kane wins a fortune and his future bride at a game of dice from the former pirate Balthasar. When he decides to go and get the girl, the pirate way, by kidnapping her, not only he finds out that she is more than a pirate could ever want from a wife... but that she has 4 identical sisters as well. This discovery hits him when his men, who were supposed to help him out, each kidnaps a different girl... and none of them gets the right one! But Wilson Kane wants the girl he had met and no one else! Luckily for him it will be the girl herself to solve his problem and put an end to his dilemma... a solution that will eventually fling her into a new life, aboard the Alidivento, across the Mediterranean Sea.') # 1280
add('Therosekiller', 'http://therosekiller.thecomicseries.com/', u'Someone has been killing members of the mob and those connected to them, then leaving a fresh rose behind at the scenes. The Big Apple becomes abuzz with talk about the "Rose Killer" as the NYPD work to crack the case and find the murderer.') # 108
add('Thewomenidraw', 'http://the-women-i-draw.thecomicseries.com/', u"This is a place for all the women I drew over many years. Some you might recognize from my strips, others you'll see here for the first time, and the rest are women I drew from other comics on ComicFury.") # 157
add('Thisisdouglas', 'http://thisisdouglas.thecomicseries.com/', u"Somewhere off the M59 Motorway lies the sleepy little town of Douglas... This is Douglas. Want a hi-tech and pretty strip? Don't look here. We do however endeavour to be Interesting.") # 360
add('Thisisnormal', 'http://thisisnormal.thecomicseries.com/', u"A view of life, the universe, and pretty much everything, as told from the perspective of me, a normal-by-my-own-personal-definition-of-the-word teenager, living in the UK today. All of my comics are true. Sure, some of them may never have happened in real life, but that doesn't make them any less true.") # 797
add('Tinytown', 'http://tinytown.thecomicseries.com/', u'Four young women and their friends embark on a summer of rambunctious (and occasionally ridiculous) adventures. Warning: May contain Pirates, Ninjas, Mimes, Clowns, Nerdy Jokes and one very annoying jester. Read with caution.') # 104
add('Tolva', 'http://tolva.thecomicseries.com/', u'In an Hostile environment a woman must find the key to her past. Little does she know that the key to her past could also be the answer to the mystery of the Tolva.') # 115
add('TomboftheKing', 'http://TomboftheKing.thecomicseries.com/', u'Epic fantasy tale with a spin of sci-fi action. Similar to Lord of the Rings, Indiana Jones and Stargate all thrown together. Greed and corruption are the motivating factor behind the quest to unlock the secrets of an ancient map written in a language unknown to the current inhabitants of the land....only one man has been able to decipher the symbols, Lexus Doctramius.') # 399
add('Tomorrowsgirls', 'http://tomorrowsgirls.thecomicseries.com/', u"Gabriel Lassiter heads up a group of mega-corporations offering almost magical technology, and amazing consumer products. But Lassiter is hiding a frightening secret that only Whitney, his personal assistant, and Steve Chin, the head of the Tomorrow Girl Agency know. And they aren't telling.") # 352
add('Toneout', 'http://toneout.thecomicseries.com/', u"Tone Out is a web comic about a bad musician in love with his neighbor. It's updated sporadically. It follows a storyline, so it's best to start from the first strip.") # 360
add('Toontowncomics', 'http://toontowncomics.thecomicseries.com/', u'I started this comic one feb. 8, 2010. These are the true events of my life.') # 101
add('Toy', 'http://toy.thecomicseries.com/', u"Tripping Over You is a love story that addresses the awkwardness that comes from having feelings for someone you shouldn't - especially in the odd mix of drama and humor that is secondary boarding school. This story contains LGBT interactions - if that's not your cup of tea, this comic may not be for you.") # 130
#add('TransUman', 'http://TransUman.thecomicseries.com/', u"Another day burns out into the night, Another night of fear and boredom. Another way that don't lead out, Another Outsider is coming. And I can't hear nobody calling. I can't see but I think that there is: Some-one out there who cares Some-where out there but who cares? Crawling Darkness takes another Light and the Dark is growing stronger. Another wrong,that can't be right. Life is long but Death is longer... And I can't see nobody coming, I can't be the only one waiting for Some-one out there who cares Some-where out there but who cares? Somewhere Out There - Machine Mother") # 508
add('Trigonometry', 'http://Trigonometry.thecomicseries.com/', u'The adventures of a gnome death knight and her friends as she struggles to find her place in the world. Set in the World of Warcraft.') # 138
add('Trollgirl', 'http://trollgirl.thecomicseries.com/', u'Amelia has the unique ability to say the most inappropriate things at the most inappropriate times. Unfortunately, that kind of skill is not appreciated when your job is to keep people from killing themselves...') # 189
add('TruFax', 'http://TruFax.thecomicseries.com/', u"Mostly true, but really just practice. This comic is bits of my life worth sharing with others. It's also serving as a platform for determining on what parts of sequential art I need some improvement, or vast improvement. Please feel free to leave constructive criticism, this is a learning experience.") # 103
add('Tussenkatersenspraakwater', 'http://Tussenkatersenspraakwater.thecomicseries.com/', u'Ontmoet Kevin, Dave en Dalton in hun dagelijkse strijd van het bestaan van een twintiger. Het is een verhaal van lekker bezig zijn, tot de grond gaan, katers wegdrinken en fietssloten doorzagen. Het is echter geen succesverhaal, niet eens een love story. Wat overblijft is een beetje politiek incorrect, een beetje disfunctioneel, maar heeft uiteindelijk het hart op de juiste plek.') # 135
#add('Underscore', 'http://Underscore.thecomicseries.com/', u'In some unknown location of Canada, we follow the lives of a small, unruly group of young adults. Unaware of what is going on in just about everywhere else in the world, they do their best surviving through their misadventures. One day at a time.') # 103
add('Unfortunatecircumstances', 'http://unfortunatecircumstances.thecomicseries.com/', u"This is my webcomic. A stream of consciousness piece of dribble that doesn't have any kind of cohesive form or topic. It's just me playing around. Have fun!") # 147
add('Unreliable', 'http://unreliable.thecomicseries.com/', u'Non-sequitur autobiographical comic-type things that will hopefully help me with my discipline.') # 276
add('Usbcomic', 'http://usbcomic.thecomicseries.com/', u'Warning: Not a pokemon sprite comic!!! Set in the year 2100 where the latest trend is artefially intelligent USB memory sticks. These can be used to help around the house, solve problems or even face off against each-other in (usually friendly) challenges. Our story follows the adventure of 16 year old Josh young; a teenager from edge-tech city, in the southwest of the UK (built in 2050, about 10 miles from Bristol).') # 343
add('V4', 'http://v4.thecomicseries.com/', u'Enemies are coming to wipe out anyone and everyone in their path. Leaders of various territories are banding together to try and survive the coming battles. Underworld creatures and sorcerers battle for power near the end of the world.') # 101
add('Verboten', 'http://verboten.thecomicseries.com/', u'The universe has always been an enigmatic place to human kind. It is said that eons ago, the only thing that existed was a dark, foreboding void. In time, however the Gods created the stars, the planets, and above all, life. This was their masterpiece work. Each God contributed a portion of their power to the creation of human kind....but....the Gods were betrayed by one of their own; The God of Time. After cursing humanity, and nearly driving the rest of the Gods to extinction, he was eventually sealed, and his powerful weapon was banished to the furthest reaches of the universe. But...there are other fearsome creatures that reside in the darkness. Evil things. Living nightmares that seep into this world from where our dimension meets another...') # 122
add('Violentblue', 'http://violentblue.thecomicseries.com/', u'A retrogamer, A comic fan, a punk Grrrl and a mean squirrel deal with life, pop culture, God and each other.') # 497
add('VisualDiary', 'http://VisualDiary.thecomicseries.com/', u'Two sides to an aspiring artist. Multiple personality disorder? Perhaps. Laughs? Definitely. "The Early Years" part of the comic that updates on Wednesday will more story based than the gags on the normal updates. Updates: Mon, Tues, Thurs, Fri - regular randomness Wednesday - "Early Years" Saturday - Art day') # 214
add('Wakethesleepers', 'http://wakethesleepers.com/', u'An ancient, deadly curse has inflicted Locke Rinannis. He now must race against time as he struggles to find a cure before his life is consumed by it. Along the way, he makes allies, confronts powerful enemies, and unearths the mystery of a lore long forgotten... (Updates every Friday)') # 145
add('Wayofthemetagamer', 'http://wayofthemetagamer.thecomicseries.com/', u"Bob buys the Dungeons and Dragons book off eBay. Hilarity ensues. Plot follows. Also tropes. Lots and lots of tropes. Also no fourth wall. Actually, it's mostly about the lack of fourth wall. We probably should have mentioned that bit right at the top. Actually, yeah, move that to the top- you're writing this LIVE?") # 241
add('Whenfoxesfly', 'http://whenfoxesfly.thecomicseries.com/', u'Starting back in 2005 (with a different host), "When Foxes Fly" is an anthro spoof of superheroes and villains. One could classify it as a Christian comic, but others might say it would more accurately be described as a webcomic presented from a Christian perspective. In any event, it follows the adventures of Filbert (a flying fox) and Rusty as they discover that childlike Faith in Eternal Truth is more powerful than any superhero or villain.') # 292
add('WindRiders', 'http://WindRiders.thecomicseries.com/', u'The world has changed. A new military project to fight terrorism; troups of warriors able to fly due to a revolutionary technolgy, raised since childhood to become fighters, killers. A dangerous technology. This world is not ours anymore...') # 109
add('Winstonsworld', 'http://winstonsworld.thecomicseries.com/', u'Updated daily, M-F Winston is a curious little boy with a big imagination. Come join him as he learns about sexism, racism, deism, communism, materialism, and joy!') # 122
add('Woodsofevil', 'http://woodsofevil.thecomicseries.com/', u'Is back.') # 169
add('Wordstoliveby', 'http://wordstoliveby.thecomicseries.com/', u"You will most likely never see anything I have drawn here because I am an awful drawer. I will however do my best to make sure this comic includes wit, sarcasm, bad language, humor, random bits of helpful (and not so helpful) information. If I can't manage that? Ah well...fuck you you judgmental jerk.") # 203
add('Wowwithatwistdamaclesandkejallcomic', 'http://Wowwithatwist-damaclesandkejallcomic.thecomicseries.com/', u'Follow the dangerous adventures of Damacles , the human warrior and kenjall a worgen') # 101
add('Wrightasrayne', 'http://wrightasrayne.thecomicseries.com/', u"Alex Rayne is a superhero. He has no powers, he isn't a boy scout, and he prefers 'vigilante', but that's what he is. Atlanta, August 2026. Alex is attacked by a group representing Sarabeth Phoenix, head of a criminal empire. When he wakes up the next morning, his mind is now in the body of teenage girl Dorothy Wright. And now as a result, he has to use his abilities and the new guise of Starchild to help Sarabeth if he wants to return to normal.") # 255
add('XTIN', 'http://XTIN.thecomicseries.com/', u'Abusive relationships, told with dragons and body parts') # 177
add('Xit', 'http://X-it.thecomicseries.com/', u'Adult oriented comix. It\'s only some pictures of naked/scantily clad women, some "one of" stories, jokes, etc, from my gallery of old sketches & stuff. Rated for adults, so that I don\'t have to censor myself.') # 264
add('Yan', 'http://yan.thecomicseries.com/', u"On GameFAQs' Contests message board (also known as Board 8), I started a Choose Your Own Adventure topic, where users could post what they wanted to happen next. After a hundred or so pages, I needed somewhere to put it. This is it. The most recent GameFAQs topic will be posted on the blog, so feel free to drop by and suggest actions.") # 1733
add('Yolt', 'http://yolt.thecomicseries.com/', u'Wherein many random events and fourth-wall shattering episodes are subjected to alternate reality thespians, continuity constables, and ardent media types - all of which is presented in LegoVision.') # 382
